$title N-GON with vertices separated by at most 1 unit
* Note this is not the same as inscribing an ngon in a circle
set i /1*6/;
alias(i,j);

parameter pi,n;
pi = 4 * arctan(1);
n = card(i);

variables 
	rho(i)		'polar radius',
	theta(i)	'polar angle',
	area		'area of n-gon';

positive variables rho,theta;
rho.up(i) = 1;
rho.fx(i)$(ord(i) eq n) = 0;
theta.fx(i)$(ord(i) eq n) = pi;

equations inscribe(i,j)	'keep points within distance of 1',
	increasing(i) 'angles must increase'
	totArea;

totArea..
area =e= 0.5*sum(i,rho(i)*rho(i-1)*sin(theta(i)-theta(i-1)));

increasing(i)$(ord(i) gt 1)..
theta(i) =g= theta(i-1);

inscribe(i,j)$(ord(j) gt ord(i))..
sqr(rho(i)) + sqr(rho(j)) - 2*rho(i)*rho(j)*cos(theta(j)-theta(i)) =l= 1;

rho.l(i) = 4*ord(i)*(n + 1 - ord(i))/sqr(n+1);
theta.l(i) = pi*ord(i)/n;

model ngon /all/;
solve ngon using nlp maximizing area;

scalar found /0/;
parameter diameter(i);
loop(i$(found eq 0),
  loop(j$(found eq 0),
    if (inscribe.l(i,j) ge 1.,
	diameter(i) = 1;
	diameter(j) = 1;
	found = 1;
    );
  );
);

$libinclude matout rho.l i
$libinclude matout theta.l i
$libinclude matout diameter i
